Changelog
=========

Here you will find the full list of changes between each Arachne release


Version 0.2.0 
-------------

Released on November 15th 2015
- Export to CSV and JSON pipeline now available 

Version 0.1.0 
--------------

Released on November 14th 2015
- First public preview release
